==> py-telegram-bot-client-5.3.5.6.tar.gz: py-telegram-bot-client-5.3.5.6/telegrambotclient/__init__.py <==
from telegrambotclient.api import (DEFAULT_API_HOST, TelegramBotAPI,
                                   TelegramBotAPIException)
from telegrambotclient.base import TelegramBotException
from telegrambotclient.bot import TelegramBot
from telegrambotclient.router import TelegramRouter
from telegrambotclient.storage import TelegramStorage


class TelegramBotClient:
    __slots__ = ("_bot_data", "_router_data", "name", "_bot_api_data")

    def __init__(self, name: str = "default-client") -> None:
        self._bot_data = {}
        self._router_data = {}
        self._bot_api_data = {}
        self.name = name

    def router(self, name: str = "default-router") -> TelegramRouter:
        router = self._router_data.get(name, None)
        if router is None:
            self._router_data[name] = TelegramRouter(name)
        return self._router_data[name]

    def create_bot(
        self,
        token: str,
        router: TelegramRouter = None,
        storage: TelegramStorage = None,
        i18n_source=None,
        bot_api: TelegramBotAPI = None,
    ) -> TelegramBot:
        bot_api = self._bot_api_data.get(
            bot_api.host if bot_api else DEFAULT_API_HOST, None)
        if bot_api is None:
            bot_api = TelegramBotAPI()
            self._bot_api_data[bot_api.host] = bot_api
        router = router or self.router()
        bot = TelegramBot(token, router, storage, i18n_source, bot_api)
        try:
            bot.user
        except TelegramBotAPIException as error:
            raise TelegramBotException("The bot is not available") from error
        else:
            self._bot_data[token] = bot
            return bot

    def bot(self, token: str) -> TelegramBot:
        return self._bot_data.get(token, None)

    async def dispatch(self, token: str, update):
        bot = self.bot(token)
        if bot is None:
            raise TelegramBotException(
                "There is not a bot with token: '{0}'".format(token))
        await bot.dispatch(update)


# default bot proxy
bot_client = TelegramBotClient()

==> py-telegram-bot-client-5.3.6.tar.gz: py-telegram-bot-client-5.3.6/telegrambotclient/__init__.py <==
from telegrambotclient.api import (DEFAULT_API_HOST, TelegramBotAPI,
                                   TelegramBotAPIException)
from telegrambotclient.base import TelegramBotException
from telegrambotclient.bot import TelegramBot
from telegrambotclient.router import TelegramRouter
from telegrambotclient.storage import TelegramStorage


class TelegramBotClient:
    __slots__ = ("bots", "routers", "name", "api_callers")

    def __init__(self, name: str = "default-client") -> None:
        self.bots = {}
        self.routers = {}
        self.api_callers = {}
        self.name = name

    def router(self, name: str = "default-router") -> TelegramRouter:
        router = self.routers.get(name, None)
        if router is None:
            self.routers[name] = TelegramRouter(name)
        return self.routers[name]

    def create_bot(
        self,
        token: str,
        router: TelegramRouter = None,
        storage: TelegramStorage = None,
        i18n_source=None,
        bot_api: TelegramBotAPI = None,
    ) -> TelegramBot:
        bot_api = self.api_callers.get(
            bot_api.host if bot_api else DEFAULT_API_HOST, None)
        if bot_api is None:
            bot_api = TelegramBotAPI()
            self.api_callers[bot_api.host] = bot_api
        router = router or self.router()
        if router.name not in self.routers:
            self.routers[router.name] = router
        bot = TelegramBot(token, router, storage, i18n_source, bot_api)
        try:
            bot.user
        except TelegramBotAPIException as error:
            raise TelegramBotException("The bot is not available") from error
        else:
            self.bots[token] = bot
            return bot

    async def dispatch(self, token: str, update):
        bot = self.bots.get(token, None)
        if bot:
            await bot.dispatch(update)


# default bot proxy
bot_client = TelegramBotClient()
